@@ -1,5 +1,5 @@
 package Beam::Wire;
-$Beam::Wire::VERSION = '1.018';
+$Beam::Wire::VERSION = '1.019';
 # ABSTRACT: Lightweight Dependency Injection Container
 
 
@@ -628,7 +628,7 @@ sub validate {
 
 
 package Beam::Wire::Exception;
-$Beam::Wire::Exception::VERSION = '1.018';
+$Beam::Wire::Exception::VERSION = '1.019';
 use Moo;
 with 'Throwable';
 use Types::Standard qw( :all );
@@ -641,7 +641,7 @@ has error => (
 
 
 package Beam::Wire::Exception::Constructor;
-$Beam::Wire::Exception::Constructor::VERSION = '1.018';
+$Beam::Wire::Exception::Constructor::VERSION = '1.019';
 use Moo;
 use Types::Standard qw( :all );
 extends 'Beam::Wire::Exception';
@@ -654,7 +654,7 @@ has attr => (
 
 
 package Beam::Wire::Exception::Config;
-$Beam::Wire::Exception::Config::VERSION = '1.018';
+$Beam::Wire::Exception::Config::VERSION = '1.019';
 use Moo;
 use Types::Standard qw( :all );
 extends 'Beam::Wire::Exception';
@@ -682,7 +682,7 @@ has '+error' => (
 
 
 package Beam::Wire::Exception::Service;
-$Beam::Wire::Exception::Service::VERSION = '1.018';
+$Beam::Wire::Exception::Service::VERSION = '1.019';
 use Moo;
 use Types::Standard qw( :all );
 extends 'Beam::Wire::Exception';
@@ -700,7 +700,7 @@ has file => (
 
 
 package Beam::Wire::Exception::NotFound;
-$Beam::Wire::Exception::NotFound::VERSION = '1.018';
+$Beam::Wire::Exception::NotFound::VERSION = '1.019';
 use Moo;
 extends 'Beam::Wire::Exception::Service';
 
@@ -716,7 +716,7 @@ has '+error' => (
 
 
 package Beam::Wire::Exception::InvalidConfig;
-$Beam::Wire::Exception::InvalidConfig::VERSION = '1.018';
+$Beam::Wire::Exception::InvalidConfig::VERSION = '1.019';
 use Moo;
 extends 'Beam::Wire::Exception::Service';
 use overload q{""} => sub {
@@ -736,13 +736,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Beam::Wire - Lightweight Dependency Injection Container
 
 =head1 VERSION
 
-version 1.018
+version 1.019
 
 =head1 SYNOPSIS
 
@@ -804,8 +806,7 @@ L<file attribute|/file>.
 =head2 config
 
 The raw configuration data. By default, this data is loaded by
-L<Config::Any|Config::Any> using the file specified by the L</file|file
-attribute>.
+L<Config::Any|Config::Any> using the file specified by the L<file attribute|/file>.
 
 See L<Beam::Wire::Help::Config for details on what the configuration
 data structure looks like|Beam::Wire::Help::Config>.
